      SUBROUTINE ZSTAI2 (IPOPS, IUSER, SCRTCH)
C-----------------------------------------------------------------------
C! does any system cleanup needed at the end of interactive AIPS session
C# Z2 System
C-----------------------------------------------------------------------
C;  Copyright (C) 1995
C;  Associated Universities, Inc. Washington DC, USA.
C;
C;  This program is free software; you can redistribute it and/or
C;  modify it under the terms of the GNU General Public License as
C;  published by the Free Software Foundation; either version 2 of
C;  the License, or (at your option) any later version.
C;
C;  This program is distributed in the hope that it will be useful,
C;  but WITHOUT ANY WARRANTY; without even the implied warranty of
C;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C;  GNU General Public License for more details.
C;
C;  You should have received a copy of the GNU General Public
C;  License along with this program; if not, write to the Free
C;  Software Foundation, Inc., 675 Massachusetts Ave, Cambridge,
C;  MA 02139, USA.
C;
C;  Correspondence concerning AIPS should be addressed as follows:
C;         Internet email: aipsmail@nrao.edu.
C;         Postal address: AIPS Project Office
C;                         National Radio Astronomy Observatory
C;                         520 Edgemont Road
C;                         Charlottesville, VA 22903-2475 USA
C-----------------------------------------------------------------------
C-----------------------------------------------------------------------
C   ZSTAI2 performs any operations needed to normalize the local
C   operating system at the conclusion of an interactive AIPS session.
C   Inputs:
C      IPOPS    I        POPS number of current AIPS
C      IUSER    I        User number of current AIPS
C   Outputs:
C      SCRTCH   I(256)   Scratch buffer
C   Generic version  - null routine, created to allow there to be a C
C   routine below ZSTAIP.
C-----------------------------------------------------------------------
      INTEGER   IPOPS, IUSER, SCRTCH(256)
C
C-----------------------------------------------------------------------
C                                       Nothing to do
C
 999  RETURN
      END
